summaryrefslogtreecommitdiff
path: root/resources/jquery.ui/jquery.ui.tabs.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/jquery.ui/jquery.ui.tabs.js')
-rw-r--r--resources/jquery.ui/jquery.ui.tabs.js11
1 files changed, 5 insertions, 6 deletions
diff --git a/resources/jquery.ui/jquery.ui.tabs.js b/resources/jquery.ui/jquery.ui.tabs.js
index ff7938ce..de453cc3 100644
--- a/resources/jquery.ui/jquery.ui.tabs.js
+++ b/resources/jquery.ui/jquery.ui.tabs.js
@@ -1,7 +1,7 @@
/*
* jQuery UI Tabs 1.8.17
*
- * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
* http://jquery.org/license
*
@@ -427,7 +427,7 @@ $.widget( "ui.tabs", {
// meta-function to give users option to provide a href string instead of a numerical index.
// also sanitizes numerical indexes to valid values.
if ( typeof index == "string" ) {
- index = this.anchors.index( this.anchors.filter( "[href$=" + index + "]" ) );
+ index = this.anchors.index( this.anchors.filter( "[href$='" + index + "']" ) );
}
return index;
@@ -698,7 +698,7 @@ $.widget( "ui.tabs", {
});
$.extend( $.ui.tabs, {
- version: "1.8.17"
+ version: "1.8.23"
});
/*
@@ -733,7 +733,6 @@ $.extend( $.ui.tabs.prototype, {
}
}
: function( e ) {
- t = o.selected;
rotate();
});
@@ -1,7 +1,7 @@
-/*
- * jQuery UI Tabs 1.8.17
+/*!
+ * jQuery UI Tabs 1.8.23
*